@@ -18,7 +18,7 @@ class BackupUtil:
 		self.src = args.src
 		self.compress = args.compress
 		self.desc = args.desc
-		self.part_size = args.partsize
+		self.part_size = args.part_size
 
 		self.vault = args.vault
 		self.region = args.region
@@ -37,7 +37,8 @@ class BackupUtil:
 		cur = self.conn.cursor()
 		try:
 			cur.execute(
-				"create table if not exists sync_history (id integer primary key, path text, file_size integer, mtime float, archive_id text, location text, checksum text, compression text, timestamp text);")
+				"create table if not exists sync_history (id integer primary key, path text, file_size integer, "
+				"mtime float, archive_id text, location text, checksum text, compression text, timestamp text);")
 			self.conn.commit()
 		except sqlite3.OperationalError as e:
 			logging.error(f"DB error. Cannot mark the file as backed up: {str(e)})")
@@ -80,10 +81,16 @@ class BackupUtil:
 
 			is_backed_up, file_size, mtime = self._check_if_backed_up(file)
 			if not is_backed_up:  # True if already backed up
-				logging.info(f"{file_index+1}/{len(file_list)} - {file} will be backed up")
+				logging.info(f"{file_index + 1}/{len(file_list)} - {file} will be backed up")
+
+				part_size = self.decide_part_size(file_size)  # decide part size for each file
+				logging.debug(f"part size is {part_size}")
+
 				file_object, compressed_file_object = self._compress(file)  # compress the file if specified
+
 				desc = f'grsync|{file}|{file_size}|{mtime}|{self.desc}'
-				archive = self._backup(compressed_file_object, desc)
+				archive = self._backup(compressed_file_object, desc, part_size)
+
 				if archive is not None:
 					logging.info(f"{file} is backed up successfully")
 				else:
@@ -92,13 +99,15 @@ class BackupUtil:
 				file_object.close()
 				self._mark_backed_up(file, archive)
 			else:
-				logging.info(f"{file_index+1}/{len(file_list)} - {file} is already backed up, skipping...")
+				logging.info(f"{file_index + 1}/{len(file_list)} - {file} is already backed up, skipping...")
+
+		logging.info("All files are processed.")
 		self.close()
 
 	def _check_if_backed_up(self, path):
 		"""
 		Check if file is already backed up
-		:param file: full file path
+		:param path: full file path
 		:return: True if file is backed up, False if file is not backed up
 		"""
 		file_size, mtime = self.__get_stats(path)  # file size and mtime should match. if not it will be backed up again
@@ -151,7 +160,8 @@ class BackupUtil:
 			del chunk
 		return self.calculate_total_tree_hash(checksums)
 
-	def calculate_total_tree_hash(self, checksums):
+	@staticmethod
+	def calculate_total_tree_hash(checksums):
 		"""
 		Calculate hash of a list
 		:param checksums: list(checksum) -> a list of checksum
@@ -170,11 +180,12 @@ class BackupUtil:
 			tree = parent
 		return tree[0]
 
-	def _backup(self, src_file_object, description):
+	def _backup(self, src_file_object, description, part_size):
 		"""
 		Send the file to glacier
 		:param src_file_object: FileCache object
 		:param description: Archive description including grsync meta
+		:param part_size: Part size for multipart upload
 		:return: archive information
 		"""
 		if src_file_object is None:  # only happens if unsupported compression algorithm
@@ -182,7 +193,7 @@ class BackupUtil:
 		try:
 			response = self.glacier.initiate_multipart_upload(
 				vaultName=self.vault,
-				partSize=str(self.part_size),
+				partSize=str(part_size),
 				archiveDescription=description
 			)
 			upload_id = response['uploadId']
@@ -190,7 +201,7 @@ class BackupUtil:
 			byte_pos = 0
 			list_of_checksums = []
 			while True:
-				chunk = src_file_object.read(self.part_size)
+				chunk = src_file_object.read(part_size)
 				if chunk is None:
 					break
 				range_header = "bytes {}-{}/*".format(
@@ -224,7 +235,7 @@ class BackupUtil:
 		"""
 		Mark the given file as archived in db with associated information
 		:param path: absolute path of the file
-		:param archive_id: glacier archive id
+		:param archive: glacier archive information
 		"""
 		if archive is None:
 			logging.error(f"{path} cannot be backed up")
@@ -241,8 +252,10 @@ class BackupUtil:
 		cur = self.conn.cursor()
 		try:
 			cur.execute(
-				f"insert into sync_history (path, file_size, mtime, archive_id, location, checksum, compression, timestamp) "
-				f"values ('{path}', {file_size}, {mtime}, '{archive_id}', '{location}', '{checksum}', '{compression}', '{timestamp}')"
+				f"insert into sync_history "
+				f"(path, file_size, mtime, archive_id, location, checksum, compression, timestamp) "
+				f"values ('{path}', {file_size}, {mtime}, '{archive_id}', '{location}', "
+				f"'{checksum}', '{compression}', '{timestamp}')"
 			)
 			self.conn.commit()
 		except sqlite3.OperationalError as e:
@@ -251,10 +264,23 @@ class BackupUtil:
 		finally:
 			cur.close()
 
-	def __get_stats(self, path):
+	@staticmethod
+	def __get_stats(path):
 		"""
 		Get the stats of given file
 		:param path: absolute path of the file
 		:return: tuple(file size, modified time)
 		"""
 		return os.path.getsize(path), os.path.getmtime(path)
+
+	def decide_part_size(self, file_size):
+		"""
+		Decide Glacier part size
+		Number of parts for multipart upload should be smaller than 10000
+		:param file_size: size of file to be uploaded
+		:return: part size for upload
+		"""
+		part_size = self.part_size
+		while file_size / part_size > 10000:
+			part_size *= 2
+		return part_size
